import os
import json

import requests
from urllib.parse import urlencode


class Stashy:
    # base_url = 'https://stashy.io/api'
    base_url = 'http://localhost:8000'
    """
    A session stores configuration state and allows you to create service
    clients and resources.
    :type api_key: string
    :param api_key: Stashy.io API key
    """

    def __init__(self, api_key=None):
        self.headers = {'content-type': 'application/json', 'Authorization': 'Bearer ' + api_key}

    def get(self, endpoint, filter_by=None, sort_by=None, order_by=None):
        if isinstance(endpoint, str) is False:
            raise Exception("Endpoint is not a valid string")
        query_params = ""
        if filter_by is not None:
            query_params = '?' + urlencode(filter_by)
        if sort_by is not None:
            query_params = query_params + '&sort=' + sort_by
        if order_by is not None:
            if order_by.lower() == 'asc' or order_by == 1 or order_by.lower() == 'desc' or order_by == -1:
                query_params = query_params + '&order=' + order_by

        url = self.base_url + '/d/' + endpoint + '/docs' + query_params
        r = requests.get(url, headers=self.headers)

        if r.status_code == 200:
            json_data = r.json()
            return {
                "url": url,
                "count": len(json_data),
                "data": json_data
            }
        else:
            return {"status": r.status_code, "message": r.reason}

    def save(self, endpoint, data=None, explode=None):
        if isinstance(endpoint, str) is False:
            raise Exception("Endpoint is not a valid string")
        query_params = ""
        if explode is not None:
            query_params = '?st::explode=' + explode
        url = self.base_url + '/d/' + endpoint + '/docs' + query_params
        r = requests.post(url, headers=self.headers, data=json.dumps(data))
        json_data = r.json()
        if r.status_code == 200:
            return {
                "url": url,
                "count": len(json_data),
                "data": json_data
            }
        else:
            return json_data

    def delete_all(self, endpoint):
        if isinstance(endpoint, str) is False:
            raise Exception("Endpoint is not a valid string")
        url = self.base_url + '/d/' + endpoint + '/docs/delete_all'
        r = requests.delete(url, headers=self.headers)
        return r.json()

    def delete(self, endpoint, filter_by=None):
        print(filter_by['st::filter'])
        if isinstance(endpoint, str) is False:
            raise Exception("Endpoint is not a valid string")
        query_params = ""
        if filter_by is not None:
            if 'st::filter' not in filter_by:
                query_params = '?' + urlencode(filter_by)
            else:
                query_params = '?st::filter=' + json.dumps(filter_by['st::filter']).replace(" ", "")
        url = self.base_url + '/d/' + endpoint + '/docs/delete' + query_params
        print(url)
        r = requests.delete(url, headers=self.headers)
        return r.text



import os

from stashyio.stashy import Stashy

__author__ = 'Stashy.io'
__version__ = '0.0.1'

# The default Boto3 session; autoloaded when needed.
STASHY = None


def authorize(api_key=None):
    """
    Create a resource service client by name using the default session.
    """
    if api_key is None:
        api_key = os.environ.get('STASHY_AP_KEY')
        if api_key is None:
            raise Exception("STASHY_API_KEY env variable not set")
    return _get_stashy(api_key)


def setup_stashy(api_key):
    """
    Set up stashyio, passing through any parameters to the session
    constructor. There is no need to call this unless you wish to pass custom
    parameters, because a default session will be created for you.
    """
    global STASHY
    STASHY = Stashy(api_key)


def _get_stashy(api_key):
    """
    Get the stashyio object, creating one if needed.
    :rtype: :py:class:`~stashy.Stashy`
    :return: The stashyio object
    """
    if STASHY is None:
        setup_stashy(api_key)

    return STASHY



#!/usr/bin/env python

"""
distutils/setuptools install script.
"""
import os
import re

from setuptools import setup, find_packages


ROOT = os.path.dirname(__file__)
VERSION_RE = re.compile(r'''__version__ = ['"]([0-9.]+)['"]''')


requires = [
    'requests>=2.18.1',
    'urllib3>=1.21.1'
]


def get_version():
    init = open(os.path.join(ROOT, 'stashyio', '__init__.py')).read()
    return VERSION_RE.search(init).group(1)


setup(
    name='stashyio',
    version=get_version(),
    description='The Stashy SDK for Python',
    author='Stashy',
    author_email='dev@stashyio.io',
    url='https://github.com/snclucas/stashy_python',
    download_url='https://github.com/snclucas/stashy_python',
    scripts=[],
    packages=['stashyio'],
    license="MIT",
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
)
